@@ -22,13 +22,13 @@
 #include "btfileindexer.h"
 #include "btparser.h"
 
+#include <KAboutData>
 #include <KConfigGroup>
 #include <KLineEdit>
-#include <kaboutdata.h>
-#include <klocalizedstring.h> // i18n
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
-#include <ksharedconfig.h>
+#include <KLocalizedString> // i18n
+#include <KPluginFactory>
+#include <KPluginLoader>
+#include <KSharedConfig>
 #include <ktexteditor/view.h>
 
 #include <QClipboard>
