@@ -19,13 +19,13 @@
 #include "katesqlconfigpage.h"
 #include "outputstylewidget.h"
 
+#include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
-#include <kconfiggroup.h>
-#include <klocalizedstring.h>
 
-#include <qboxlayout.h>
-#include <qcheckbox.h>
-#include <qgroupbox.h>
+#include <QBoxLayout>
+#include <QCheckBox>
+#include <QGroupBox>
 
 KateSQLConfigPage::KateSQLConfigPage(QWidget *parent)
     : KTextEditor::ConfigPage(parent)
