@@ -22,18 +22,18 @@
 
 #include "kateconsole.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <ktexteditor/document.h>
 #include <ktexteditor/message.h>
 #include <ktexteditor/view.h>
 
+#include <KActionCollection>
+#include <KShell>
 #include <QAction>
-#include <kactioncollection.h>
 #include <kde_terminal_interface.h>
 #include <kparts/part.h>
-#include <kshell.h>
 
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 #include <QApplication>
 #include <QCheckBox>
@@ -47,14 +47,13 @@
 #include <QStyle>
 #include <QVBoxLayout>
 
+#include <KAboutData>
 #include <KAuthorized>
 #include <KConfigGroup>
 #include <KPluginFactory>
 #include <KPluginLoader>
 #include <KSharedConfig>
 #include <KXMLGUIFactory>
-#include <kaboutdata.h>
-#include <kpluginfactory.h>
 
 K_PLUGIN_FACTORY_WITH_JSON(KateKonsolePluginFactory, "katekonsoleplugin.json", registerPlugin<KateKonsolePlugin>();)
 
