@@ -21,9 +21,9 @@
 #include "kateprojectinfoviewindex.h"
 #include "kateprojectpluginview.h"
 
+#include <KLocalizedString>
+#include <KMessageWidget>
 #include <QVBoxLayout>
-#include <klocalizedstring.h>
-#include <kmessagewidget.h>
 
 KateProjectInfoViewIndex::KateProjectInfoViewIndex(KateProjectPluginView *pluginView, KateProject *project, QWidget *parent)
     : QWidget(parent)
