@@ -20,8 +20,8 @@
 
 #include "kateprojectcodeanalysistoolshellcheck.h"
 
+#include <KLocalizedString>
 #include <QRegularExpression>
-#include <klocalizedstring.h>
 
 KateProjectCodeAnalysisToolShellcheck::KateProjectCodeAnalysisToolShellcheck(QObject *parent)
     : KateProjectCodeAnalysisTool(parent)
