@@ -24,11 +24,11 @@
 #include <KSharedConfig>
 #include <KUrlRequester>
 
+#include <KLocalizedString>
 #include <QGridLayout>
 #include <QLabel>
 #include <QLayout>
 #include <QTabWidget>
-#include <klocalizedstring.h>
 
 ReplicodeConfigPage::ReplicodeConfigPage(QWidget *parent)
     : KTextEditor::ConfigPage(parent)
