@@ -42,16 +42,16 @@
 
 #include "plugin_katesymbolviewer.h"
 
+#include <KAboutData>
 #include <KActionCollection>
 #include <KConfigGroup>
+#include <KLocalizedString>
+#include <KPluginFactory>
+#include <KPluginLoader>
 #include <KSharedConfig>
+#include <KToggleAction>
 #include <KXMLGUIFactory>
 #include <QAction>
-#include <kaboutdata.h>
-#include <klocalizedstring.h>
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
-#include <ktoggleaction.h>
 
 #include <ktexteditor/configinterface.h>
 #include <ktexteditor/cursor.h>
