@@ -22,9 +22,9 @@
 #include <QCoreApplication>
 #include <QDBusConnectionInterface>
 #include <QDBusReply>
-#include <QStringList>
 #include <QFileInfo>
 #include <QRegularExpression>
+#include <QStringList>
 
 int KateRunningInstanceInfo::dummy_session = 0;
 
@@ -43,8 +43,7 @@ bool fillinRunningKateAppInstances(KateRunningInstanceMap *map)
     }
 
     const bool inSandbox = QFileInfo::exists(QStringLiteral("/flatpak-info"));
-    const QString my_pid = inSandbox ? QDBusConnection::sessionBus().baseService().replace(QRegularExpression(QStringLiteral("[\\.:]")), QStringLiteral("_"))
-                                     : QString::number(QCoreApplication::applicationPid());
+    const QString my_pid = inSandbox ? QDBusConnection::sessionBus().baseService().replace(QRegularExpression(QStringLiteral("[\\.:]")), QStringLiteral("_")) : QString::number(QCoreApplication::applicationPid());
 
     for (const QString &s : qAsConst(services)) {
         if (s.startsWith(QLatin1String("org.kde.kate")) && !s.endsWith(my_pid)) {
